function getBabelConfig(opts) {
  const options = opts || {};
  const src = options.src || process.cwd() + '/src';

  const config = {
    sourceMaps: true,
    ignore: [
      'node_modules',
    ],
    presets: [
      {
        plugins: [
          'transform-async-to-generator',
          'transform-object-rest-spread',
          ['module-resolver', {
            root: [src],
          }],
        ],
      },
      // env presets will go here
      {
        plugins: [
          'syntax-async-functions',
          'syntax-trailing-function-commas',
          'syntax-dynamic-import',
        ],
      },
    ],
  };

  const environments = {
    client: {
      presets: [
        ['env', {
          targets: {
            browsers: ['last 2 versions'],
            uglify: true,
          },
        }],
        'react',
      ],
    },
    webpack: {
      presets: [
        ['env', {
          targets: {
            browsers: ['last 2 versions'],
            uglify: true,
          },
          modules: false,
        }],
        'react',
      ],
    },
    test: {
      presets: [
        {
          plugins: [
            ['istanbul', {
              exclude: [
                '**/*.spec.js',
                '**/*-spec.js',
                '**/*.test.js',
                '**/*-test.js',
              ],
            }],
          ],
        },
        ['env', {
          targets: {
            node: 'current',
          },
          exclude: [
            'transform-regenerator',
          ],
        }],
        'react',
      ],
    },
    server: {
      presets: [
        ['env', {
          targets: {
            node: 'current',
          },
          exclude: [
            'transform-regenerator',
          ],
        }],
        'react',
      ],
    },
  };

  const env = options.env || process.env.BABEL_ENV || 'webpack';
  const envConfig = environments[env];

  if (!envConfig) {
    throw new Error(`Invalid Babel environment. Must be one of ${Object.keys(environments).join(', ')}`);
  }

  for (let i = 0; i < envConfig.presets.length; i += 1) {
    config.presets.splice(i + 1, 0, envConfig.presets[i]);
  }

  return config;
}

module.exports = getBabelConfig;
